@@ -12,14 +12,17 @@
 #
 #      You should have received a copy of the GNU Affero General Public License
 #      along with this program.  If not, see <https://www.gnu.org/licenses/>.
-from bootstrap_datepicker_plus import TimePickerInput, DatePickerInput
+from bootstrap_datepicker_plus.widgets import TimePickerInput, DatePickerInput
 from bootstrap_modal_forms.forms import BSModalModelForm
 from bootstrap_modal_forms.mixins import CreateUpdateAjaxMixin, PopRequestMixin
 from crispy_forms.helper import FormHelper
 from crispy_forms.layout import Submit, Layout, Div, Field
 from django import forms
+from django.conf import settings
 from django.contrib import messages
+from django.contrib.auth import get_user_model
 from django.core.exceptions import ValidationError
+from django.db.models import Q
 from django.forms import ModelForm
 from django.forms.renderers import get_default_renderer
 from django.utils import timezone
@@ -111,23 +114,12 @@ class PresenceCreateForm(BSModalModelForm):
                 })
 
         super(PresenceCreateForm, self).__init__(*args, **kwargs)
+        # if not preselect image before add
         if self.classroom:
             if self.child_pk is None:
                 self.fields['child'].queryset = Child.objects.filter(classroom=self.classroom,
                                                                      status=Child.STATUS.in_progress)
 
-        # self.helper = FormHelper()
-        # self.helper.form_method = 'post'
-        # self.helper.form_show_labels = True
-        # self.helper.form_tag = False
-        # self.helper.layout = Layout(
-        #     Div(
-        #         Field("child", wrapper_class="col-sm-12 col-md-12"),
-        #         Field("arrival_time", wrapper_class="col-sm-12 col-md-6"),
-        #         Field("departure_time", wrapper_class="col-sm-12 col-md-6"),
-        #         css_class="row",
-        #     )
-        # )
 
     def save(self, commit=True):
         if not self.request.is_ajax():
@@ -426,10 +418,17 @@ class ChoiceClassroomForm(forms.ModelForm):
         # get userid from view
         userid = kwargs.pop("userid")
         super(ChoiceClassroomForm, self).__init__(*args, **kwargs)
+        user = get_user_model()
+        user = user.objects.get(id=userid)
+        group = user.groups.values_list('id', flat=True)
 
         # create field id for form with only the child class of login
-        self.fields['id'] = forms.ModelChoiceField(label=_("Classroom"),
-                                                   queryset=Classroom.objects.filter(allowed_login=userid))
+        self.fields['id'] = forms.ModelChoiceField(
+            label=_("Classroom"),
+            queryset=Classroom.objects.filter(
+                Q(allowed_login=userid) | Q(allowed_group_login__in=group)
+            ).distinct()
+        )
 
         self.helper = FormHelper()
         self.helper.form_id = 'id-choice-classroom-index-form'
